#ifndef HS_Net_H
#define HS_Net_H
/* ____________________________________________________________________________
#  Copyright (c) 2005
# 	Helicomm Inc.  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are prohibited without the written consents of Helicomm, Inc.
#
#  THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* _____________________________________________________________________________
*/



#include "../DataDef.h"

// FRAME_TYPE
/// Nwk layer frame type: DATA
#define NWK_FT_DATA                        0
/// Nwk layer command frame
#define NWK_FT_COMMAND                     1

/// Nwk state: idle
#define HS_NET_IDLE_MODE                   0
/// Nwk state: sending frame
#define HS_NET_SEND_MODE                   1
/// Nwk state: receiving frame
#define HS_NET_RECEIVE_MODE                2

/// Macro used for retrieving the current state of the Nwk layer
#define HS_NET_MODE()                      (HS_NetLayerCtrl.Mode)

typedef struct tag_CAPABILITY_INFORMATION_FIELD
{
  unsigned char   AlternatePANcoordiantor    :1;
  unsigned char   DeviceType                 :1;
  unsigned char   PowerSource                :1;
  unsigned char   ReceiverOnWhenIdle         :1;
  unsigned char   Reserved                   :2;
  unsigned char   SecurityCapability         :1;
  unsigned char   AllocateAddress            :1;
}CAPABILITY_INFORMATION_FIELD;


typedef struct tag_HS_NET_LAYER_CTRL
{
    unsigned char         Mode;
    unsigned char         State;
    unsigned short        wWaitTimeoutCount;
    unsigned char         byRetryCount;
}HS_NET_LAYER_CTRL; 

#define SET_HS_RUN_MODE                    SetHsRunMode
#define SET_AODV_RUN_MODE                  SetHsAodvMode
#define SET_HS_RUN_BROADCAST_MODE          SetHsBroadcastMode
//broadcast
#define HS_NET_RUN__BROADCAST_IDLE                      0
#define HS_NET_RUN__BROADCAST_PACKET_SEND               1
#define HS_NET_RUN__BROADCAST_WAIT_NEIGHBOR             2
#define HS_NET_RUN__RETRY_SEND_BROADCAST                3

//aodv
#define HS_NET_RUN_SEND__AODVJR_IDLE                    0
#define HS_NET_RUN_SEND__AODVJR_RREQ_PACKET             1
#define HS_NET_RUN_SEND__AODVJR_WAIT_RREP_PACKET        2
#define HS_NET_RUN_SEND__RETRY_AODVJR_RREQ_PACKET       3
#define HS_NET_RUN_SEND__AODVJR_UNICAST_RREQ            4
#define HS_NET_RUN_SEND__AODVJR_BROADCAST_RREQ          5
#define HS_NET_RUN_SEND__AODVJR_REPLY_WITH_RREP         6
#define HS_NET_RUN_SEND__AODVJR_UNICAST_RREP            7
#define HS_NET_RUN_SEND__AODVJR_FIND_NEW_ROUTING_PATH   8
#define HS_NET_RUN_SEND__AODVJR_LEAVE_PACKET            9
#define HS_NET_RUN_SEND__AODVJR_WAIT_INDICATION_PACKET  10

#define HS_NET_RUN_IDLE                    0

#define HS_NET_RUN_SEND__MAC_PACKET_SEND   1
#define HS_NET_RUN_SEND__FINISH            9

extern  unsigned char        xdata         nwkcCoordinatorCapable;

#define  COORDINATOR_TYPE                  0
#define  ROUTER_TYPE                       1
#define  END_DEVICE_TYPE                   2


//define temp
#define ENC_MIC_64                         0

#define nwkcDefaultSecurityLevel           ENC_MIC_64
#define nwkcDiscoveryRetryLimit            3
#define nwkcMaxDepth                       7
#define nwkcMaxFrameOverhead               13
#define nwkcMaxPayloadSize                 (aMaxMACFrameSize-aMaxFrameOverhead)
#define nwkcProtocolVersion                1
#define nwkcRepairThreshold                3
#define nwkcRouteDiscoveryTime             10000
#define nwkcMaxBroadcastJitter             64
#define nwkcInitialRREQRetries             3
#define nwkcRREQRetries                    2
#define nwkcRREQRetryInterval              254
#define nwkcMinRREQJitter                  1
#define nwkcMaxRREQJitter                  64 

#ifndef tag_NWK_ENUM
  #define tag_NWK_ENUM
  typedef BYTE  NWK_ENUM;
#endif

// Nwk layer enumeration
#ifndef SUCCESS
   #define SUCCESS                       0x00
#endif
#define NWK_INVALID_PARAMETER            0xc1
#define INVALID_REQUEST                  0xc2
#define NOT_PERMITTED                    0xc3
#define STARTUP_FAILURE                  0xc4
#define ALREADY_PRESENT                  0xc5
#define SYNC_FAILURE                     0xc6
#define TABLE_FULL                       0xc7
#define UNKNOWN_DEVICE                   0xc8
#define NWK_UNSUPPORTED_ATTRIBUTE        0xc9 

#define NWK_MAX_NEIGHBOR_TABLE_ENTRYS    8
#define NWK_MAX_ROUTING_TABLE_ENTRYS     8

#define MAX_CONFIRM_BUFFER_SIZE          240
#define MAX_USE_CHANNEL_COUNT            5   

// Bit masks
#define NWK_FRAME_TYPE_BM                0x03
#define NWK_PROTOCOL_VERSION_BM          0x3C
#define NWK_DISCOVER_ROUTE_BM            0xC0
#define NWK_SECURITY_ENABLE_BM           0x02

//indicate bit from NWK to UPLayer
#define N_DATA_CFM                                          0x01
#define N_DATA_IND                                          0x02
#define N_DISC_CFM                                          0x03
#define N_JOIN_CFM                                          0x04
#define N_JOIN_IND                                          0x05
#define N_DJOIN_CFM                                         0x06
#define N_LEAVE_IND                                         0x07
#define N_LEAVE_CFM                                         0x08
#define N_SYNC_IND                                          0x09
#define N_GET_CFM                                           0x10
#define N_SET_CFM                                           0x11

#define ROUTE_STATUS_ACTIVE                                 0x00
#define ROUTE_STATUS_DISCOVERY_UNDERWAY                     0x01
#define ROUTE_STATUS_DISCOVERY_FAILED                       0x02
#define ROUTE_STATUS_INACTIVE                               0x03

#define HPP_NET_CMD_ERROR                                   0xFF
#define HPP_NET_DATA_ERROR                                  0xFF



//-------------------------------------------------------------------------------------------------------
// NWK information base

// These constants shall be used with nlmeSetRequest and nlmeGetRequest.
typedef enum {
    NWK_BSCN = 0x81,
    NWK_PASSIVE_ACK_TIMEOUT,
    NWK_MAX_BROADCAST_RETRIES,
    NWK_MAX_CHILDREN,
    NWK_MAX_DEPTH,
    NWK_MAX_ROUTERS,
    NWK_NEIGHBOR_TABLE,
    NWK_NETWORK_BROADCAST_DELIVERY_TIME,
    NWK_REPORT_CONSTANT_COST,
    NWK_ROUTE_DISCOVERY_RETRIES_PERMITTED,
    NWK_ROUTE_TABLE,
	NWK_SECURE_ALL_FRAMES,
    NWK_SECURITY_LEVEL,
    NWK_SYM_LINK,
    NWK_CAPABILITY_INFORMATION
} NWK_NIB_ATTR;

#define NEIGHBOR_TABLE_OPT_INFORMATION
typedef struct{
    WORD    panId;
    QWORD   extendedAddress;
    WORD    networkAddress;
    BYTE    deviceType;
    BOOL    rxOnWhenIdle;
    BYTE    relationShip;
#ifdef  NEIGHBOR_TABLE_OPT_INFORMATION
    BYTE    depth;
    BYTE    beaconOrder;
    BOOL    permitJoining;
    BYTE    transmitFailure;
    BYTE    potentialParent;
    BYTE    LQI;
    BYTE    logicalChannel;
    BYTE    incomingBeaconTimestamp[3];
    BYTE    beaconTransmitTimeoffset[3];
#endif
}NWK_NEIGHBOR_TABLE_ENTRY; 

typedef enum {
    NEIGHBOR_FIELD_PAN_ID = 0x00,
    NEIGHBOR_FIELD_EXTENDED_ADDRESS,
    NEIGHBOR_FIELD_NETWORK_ADDRESS,
    NEIGHBOR_FIELD_DEVICE_TYPE,
    NEIGHBOR_FIELD_RX_ON_WHEN_IDLE,
    NEIGHBOR_FIELD_RELATIONSHIP,
    NEIGHBOR_FIELD_DEPTH,
    NEIGHBOR_FIELD_BEACON_ORDER,
    NEIGHBOR_FIELD_PERMIT_JOINING,
    NEIGHBOR_FIELD_TRANSMIT_FAILURE,
    NEIGHBOR_FIELD_POTENTIAL_PARENT,
    NEIGHBOR_FIELD_LQI,
    NEIGHBOR_FIELD_LOGICAL_CHANNEL,
    NEIGHBOR_FIELD_INCOMING_BEACON_TIME_STAMP,
    NEIGHBOR_FIELD_BEACON_TRANSMIT_TIME_OFFSET
}NEIGHBOR_TABLE_FILED_ID;

// Routing table entry format
typedef struct
{
    WORD    destinationAddress;
    BYTE    status;
    WORD    nexthopAddress;
}NWK_ROUTING_TABLE_ENTRY;

typedef struct
{
    BYTE                        nwkBCSN;
	BYTE                        nwkPassiveAckTimeout;
	BYTE                        nwkMaxBroadcastRetries;
	BYTE                        nwkMaxChildren;
	BYTE                        nwkMaxDepth;
	BYTE                        nwkMaxRouters;
	NWK_NEIGHBOR_TABLE_ENTRY    nwkNeighborTable[NWK_MAX_NEIGHBOR_TABLE_ENTRYS];
	BYTE                        nwkNetworkBroadcastDeliveryTime;
	BYTE                        nwkReportConstantCost;
	BYTE                        nwkRouteDiscoveryRetriesPermitted;
    NWK_ROUTING_TABLE_ENTRY     nwkRoutingTable[NWK_MAX_ROUTING_TABLE_ENTRYS];
	BYTE                        nwkSecureAllFrames;
    BYTE                        nwkSecurityLevel;
	BOOL                        nwkSymLink;
	BYTE                        nwkCapapilityInformation;
}NWK_NIB; 
extern NWK_NIB xdata  nnib; 

#define NWK_NIB_RM_DEFAULT_VALUE  3
#define NWK_NIB_CM_DEFAULT_VALUE  5
#define NWK_NIB_LM_DEFAULT_VALUE  3


//  NWK layer information fields
typedef struct
{
    BYTE                        protocolID;
    BYTE                        stackProfile          :  4;
    BYTE                        nwkProtocolVersion    :  4;
    BYTE                        nwkSecurityLevel      :  3;
    BYTE                        deviceRouterCapacity  :  1;
    BYTE                        deviceDepth           :  3;
    BYTE                        deviceCapacity        :  1;
    BYTE                        TxOffset[3];
}NWK_INFORMATION_FIELDS;
extern NWK_INFORMATION_FIELDS  xdata nwkInformationFields;

/**
 * \brief Data structur of nldeDataRequest parameter list
 *
 * Used for the application layer to interface with nldeDataRequest. Users need to 
 * store arguments in it and send its address pointer to the function.
 */
typedef struct
{
	///	The network address of the entity or entities to which the NSDU is being transferred.
    WORD  dstAddr;
	/// The handle associated with the NSDU to be transmitted by the NWK layer entity.
    BYTE  nsduHandle;
	/// The distance, in hops, that a broadcast frame will be allowed to travel through the network.
    BYTE  broadcastRadius;
	///	The DiscoverRoute parameter may be used to enable route discovery operations for the transit of this frame
    BOOL  discoverRoute;
	/// The SecurityEnable parameter may be used to enable NWKL layer security processing for the current frame.       
    BOOL  securityEnable;
	///	The number of octets comprising the NSDU to be transferred.
    BYTE  nsduLength;
	/// A pointer to the packet payload
    BYTE  *pNsdu;
}NLDE_DATA_REQUEST; 

/**
 * \brief Data structure of nldeDataIndication parameter list
 *
 * This data structure is used for the upper layer to retrieve data received from the NWK
 * layer. 
 *
 */
typedef struct {
	/// The individual device address from which the NSDU originated
	WORD    srcAddress;   
    /// The link quality indication delivered by the MAC on receipt of this frame as a parameter of the MCPS-DATA.indication primtitive 
    BYTE    linkQuality;
	/// The number of octets comprising the NSDU being indicated
	BYTE    nsduLength;
	/// The pointer to the set of octets comprising the NSDU being indicated
    BYTE    *pNsdu;
}NLDE_DATA_INDICATION;

/**
 * \brief Data structure of nldeDataConfirm parameter list
 *
 * Used to confirm with the status of nlmeDataRequest. The upper layer needs to parse 
 * the structure for status and corresponding handle.
 */

typedef struct
{
	/// INVALID_REQUEST or any status values returned from security suite or the MCPSDATA.confirm primitive          (SUCCESS | TRANSACTION_OVERFLOW | TRANSACTION_EXPIRED | CHANNEL_ACCESS_FAILURE
	NWK_ENUM   status;
	/// A handle to this packet from the mcpsDataRequest() function
 	BYTE       nsduHandle;	
}NLDE_DATA_CONFIRM; 


/**
 * \brief Data structure of the description of an operating network
 *
 *  This data structure gives a detailed account of the contents 
 *        of a network descriptor. The content describes the property 
 *        of an operating network
 *
 */
// NETWORD discovery primitive
typedef struct {
	  /// The 16-bit PAN identifier of the dis-covered network. The 2 highest-order bits of this parameter are reserved and shall be set to 0
	  WORD    panID;
	  /// The current logical channel occupied by the network.
	  BYTE	  logicalChannel;
	  /// A ZigBee stack profile identifier indicating the stack profile in use in the discovered network.
	  BYTE    stackProfile;
	  /// The version of the ZigBee protocol in use in the discovered network.
	  BYTE    zigBeeVersion;
	  /// This specifies how often the MAC sub-layer beacon is to be transmitted by a given device on the network.
	  BYTE    beaconOrder;
	  /// For beacon-enabled networks, i.e. beacon order < 15, this specifies the length of the active period of the superframe.
	  BYTE    superFrameOrder;	  
	  ///  Value of TRUE indicates that at least one ZigBee router on the network currently permits joining, i.e. its NWK has been issued an NLME-PERMIT-JOINING primitive and the time limit, if given, has not yet expired.
	  BOOL	  permitJoining;
	  ///  The security level used in a security-enabled PAN. This parameter is not specified in v1.0 spec.
	  BYTE    securityLevel;
}NETWORK_DESCRIPTOR;


/**
 * \brief Data structure for the parameter list of nlmeNetworkDiscoveryConfirm
 *
 * This primitive reports the results of a network discovery operation.
 * 
 *
 */
typedef struct{
	  /// Gives the number of networks discovered by the search
	  BYTE				    NetworkCount;
	  /// A list of descriptors, one for each of the networks discovered. 
	  NETWORK_DESCRIPTOR	nwkDescriptor[MAX_USE_CHANNEL_COUNT];
	  /// Results. Any status value returned with the MLME-SCAN.confirm primitive.
	  NWK_ENUM	 	    	Status;
}NLME_NETWORK_DISCOVERY_CONFIRM;

/**
 * \brief Data structure for the paramter list of nlmeJoinIndication
 *
 * This data stucture contains all arguments of nlmeJoinIndication. Currently, it is indicated to 
 * the the next higher layer with a shared buffer. The next higher layer needs to poll and 
 * parse the data accordingly.
 */
typedef struct {
	  /// The network address of an entity that has been added to the network.
	  WORD      shortAddress;       
	  /// The 64-bit IEEE address of an entity that has been added to the network. 
	  ADDRESS   extendedAddress;
	  /// Specifies the operational capabilities of the joining device.
	  BYTE      capabilityInformation;
}NLME_JOIN_INDICATION;

/**
 * The data structure for nlmeJoinConfirm
 * 	 
 * This data structer contains the arguments of a nlmeJoinConfirm. The upper layer needs
 * to parse data accordingly
 */
// JOIN  network primitive
typedef struct{
	/// The PAN identifier from the NLME-JOIN.request to which this is a confirmation. The 2 highest-order bits of this parameter are reserved and should be set to 0.
    WORD PANId;
	/// INVALID_REQUEST, NOT_PERMITTED or any status value returned from the MLME-ASSOCIATE.confirm primitive or the MLME-SCAN.confirm primitive (SUCCESS, CHANNEL_ACCESS_FAILURE, NO_ACK,_NO_DATA, UNAVAILABLE_KEY, FAILED_SECURITY_CHECK.)
    NWK_ENUM Status;	
}NLME_JOIN_CONFIRM;

/**
 * The data structure of nlmdDirectJoinConfirm
 *
 * This data structure contains the paramters for a nlmeDirectJoinConfirm. The caller of 
 * nlmeJoinRequest shall parse the data in the shared buffer for these parameters.
 *
 */
// Direct JOIN primitive
typedef struct{
	  /// The 64-bit IEEE address in the request to which this is a confirmation.
	  ADDRESS deviceAddress;
	  /// The status of the corresponding request. SUCCESS, TABLE_FULL, or ALREADY_PRESENT
	  NWK_ENUM status;
}NLME_DIRECT_JOIN_CONFIRM;
// bitNwkDirectJnConfirm - polled this bit for reading this structure

/*
 * Data structure for nlmeLeaveIndication.
 *
 */
// LEAVE network primitive
typedef struct {
	  /// he 64-bit IEEE address of an entity that has removed itself from the network or NULL in the case that the device issuing the primitive has been removed from the network by its parent.
	  ADDRESS   extendedAddress;
}NLME_LEAVE_INDICATION;

/*
 * Data structure for nlmeLeaveConfirm
 *
 * This data structure contains parameters of a nlmeLeaveConfirm. The caller of nlmeLeaveRequest
 * shall parse the data in the shared buffer for these paramters.
 */
typedef struct{
	  /// The 64-bit IEEE address in the request to which this is a confirmation or null if the device requested to remove itself from the network.
	  ADDRESS deviceAddress;
	  /// INVALID_REQUEST, UNKNOWN_DEVICE or any status value returned from MLME-DISASSOCIATE.confirm primitive.
	  NWK_ENUM status;
}NLME_LEAVE_CONFIRM;

//REPAIR network primitive
typedef struct {
	  ADDRESS   extendedAddress;
}NLME_REPAIR_INDICATION;

typedef struct{
	  ADDRESS deviceAddress;
	  NWK_ENUM status;
}NLME_REPAIR_CONFIRM;
//  GET  and  SET  primitive

/**
 * Data structure of nlmeGetConfirm
 *
 * This data structure contains parameters of a nlmeGetConfirm. 
 * The caller of nlmeGetRequest needs to parse data of a shared
 * buffer to get these parameters.
 */
typedef struct{
	/// The results of the request to read a NIB attribute value
	NWK_ENUM      status;
	/// The identifier of the NIB attribute that was read.
	NWK_NIB_ATTR  NIBAttribute;
	/// The length, in octets, of the attribute value being returned.
	WORD          NIBAttributeLength;
	/// The value of the NIB attribute that was read.
	BYTE          *pNIBAttributeValue;
}NLME_GET_CONFIRM;

/**
 * Data structure of nlmeGetConfirm
 *
 * This data structure contains parameters of a nlmeSetConfirm. 
 * The caller of nlmeSetRequest needs to parse data of a shared
 * buffer to get these parameters.
 */
typedef struct{
	///	The result of the request to write the NIB Attribute.
    NWK_ENUM        status;
	///	The identifier of the NIB attribute that was written.
    NWK_NIB_ATTR    NIBAttribute;
}NLME_SET_CONFIRM;
/**
 * Data structure of buffer containing data sent from NWK to application layer
 *
 * This buffer is for the NWK to send data to the upper layer. The application
 * layer needs to poll this buffer for coming events.
 */
typedef struct{
	/// The primitive ID, including both confirm and indications from the NWK
    BYTE            confirmId;
	/// Buffer holding the parameters, if any, of a primtive.
	BYTE            buffer[MAX_CONFIRM_BUFFER_SIZE];
}NLME_CONFRIM_BUFFER;
/// Global variable for the buffer
extern   NLME_CONFRIM_BUFFER       xdata       nlmeConfirm; 


extern          bit                          bitNlmeToUserIo; 
extern          bit                          bitNlmeToUplayer; 
extern          bit                          bitIsLevelTwoTest;

#define GET_LOCAL_NWK_ADDRESS()        (mpib.macShortAddress)

#define NWK_BUFFER_SIZE    123

typedef struct tag_NWK_FRAME_CONTROL
{
  unsigned short     Reserved2         :1;
  unsigned short     Security          :1;
  unsigned short     Reserved3         :6;

  unsigned short     FrameType         :2;
  unsigned short     ProtocolVersion   :4;
  unsigned short     DiscoverRoute     :1;
  unsigned short     Reserved1         :1;
}NWK_FRAME_CONTROL;

typedef struct tag_NWK_LONG_HEADER
{
  NWK_FRAME_CONTROL  wFrameControl;
  unsigned short     wDestinationAddress;
  unsigned short     wSourceAddress;
  unsigned char      byBroadcastRadius;
  unsigned char      byBroadcastSequenceNumber;
}NWK_LONG_HEADER;

typedef struct tag_NWK_SHORT_HEADER
{
  NWK_FRAME_CONTROL  wFrameControl;
  unsigned short     wDestinationAddress;
  unsigned short     wSourceAddress;
}NWK_SHORT_HEADER;

typedef union tag_MSDU_BUFFER
{
  union{
    NWK_SHORT_HEADER         ShortHeader;
    NWK_LONG_HEADER          LongHeader;
  }Header;
  unsigned char      Buffer[NWK_BUFFER_SIZE];
}MSDU_BUFFER;

//-------------------------------------------------------------------------------------------------------
//  void nldeDataRequest(WORD dstAddr,BYTE nsduLength,BYTE *pNsdu,BYTE nsduHandle,BYTE broadcastRadius,BOOL discoverRoute,BOOL securityEnable)
//
//  DESCRIPTION:
//      Transmit a data packet.
//
//  PARAMETERS:
//      WORD dstAddr
//          The network address of the entity or entities to which the NSDU is being transferred.
//      BYTE nsduLength
//          The number of octets comprising the NSDU to be transferred. 
//      BYTE *pNsdu
//          A pointer to the packet payload
//      BYTE nsduHandle
//          The handle associated with the NSDU to be transmitted by the NWK layer entity.
//      BYTE broadcastRadius
//          The distance, in hops, that a broadcast frame will be allowed to travel through the network.
//      BOOL discoverRoute
//          The DiscoverRoute parameter may be used to enable route discovery operations for the transit of this frame
//          TRUE = enable route discovery,FALSE = disable route discovery
//      BOOL securityEnable
//          The SecurityEnable parameter may be used to enable NWKL layer security processing for the current frame.       
//-------------------------------------------------------------------------------------------------------
void nldeDataRequest(NLDE_DATA_REQUEST   *pNldeDataRequest); 

//-------------------------------------------------------------------------------------------------------
//  void nldeDataConfirm(NWK_ENUM status,BYTE nsduHandle)
//
//  DESCRIPTION:
//      NWK callback to the higher layer upon complete processing of a nldeDataRequest
//      Function must be implemented by the higher layer
//
//  PARAMETERS:
//      NWK_ENUM status
//           INVALID_REQUEST or any status values returned from security suite or the MCPSDATA.confirm primitive
//          (SUCCESS | TRANSACTION_OVERFLOW | TRANSACTION_EXPIRED | CHANNEL_ACCESS_FAILURE
//           INVALID_GTS | NO_ACK | UNAVAILABLE_KEY | FRAME_TOO_LONG | FAILED_SECURITY_CHECK)
//      BYTE msduHandle,
//          A handle to this packet from the mcpsDataRequest() function
//-------------------------------------------------------------------------------------------------------
void nldeDataConfirm(NWK_ENUM status,BYTE nsduHandle); 

//-------------------------------------------------------------------------------------------------------
//  void nlmeNetworkDiscoveryRequest(UINT32 scanChannels, UINT8 scanDuration)
//
//  DESCRIPTION:
///      \brief This function is called to request that the NWK layer discover networks currently operating within the POS.
///
//  PARAMETER:
///      \param scanChannels
///          The five most significant bits (b27, ... ,b31) are reserved. The 27 least significant bits (b0, b1, ... b26)
///           indicate which channels are to be scanned (1 = scan, 0 = do not scan) for each of the 27 valid channels.
///      \param scanDuration
///          A value used to calculate the length of time to spend scanning each channel.
///
//-------------------------------------------------------------------------------------------------------
void nlmeNetworkDiscoveryRequest(UINT32 scanChannels, UINT8 scanDuration);

//-------------------------------------------------------------------------------------------------------
//  void nlmeNetworkDiscoveryConfirm (BYTE networkCount, NETWORK_DESCRIPTOR *pNetworkDescriptor, MAC_ENUM status)
//
//  DESCRIPTION:
///     This function reports the results of a network discovery operation.
//
//  PARAMETER:
///     \param networkCount
///		   BYTE. Gives the number of networks discovered by the search.
///		\param  *pNetworkDescriptor
///        NETWORK_DESCRIPTOR. A pointer to a list of descriptors, one for each of the networks discovered.
///     \param  status
///        MAC_ENUM. Any Status value returned with the function mlmeScanRequest.
//-------------------------------------------------------------------------------------------------------
void nlmeNetworkDiscoveryConfirm (BYTE networkCount, NETWORK_DESCRIPTOR *pNetworkDescriptor, NWK_ENUM status);


//-------------------------------------------------------------------------------------------------------
//   NWK_ENUM nlmeNetworkFormationRequest(UINT32 scanChannels, BYTE scanDuration, BYTE beaconOrder, BYTE superframeOrder, WORD panID, BOOL batteryLifeExtension)
//
//   DESCRIPTION:
///      \brief This primitive allows the next higher layer to request 
///		that the device start a new ZigBee network with itself as the coordinator.

///
//   PARAMETERS:
///			\param scanChannels 
///          The five most significant bits (b27, ... ,b31) are reserved. The 27 least significant bits (b0, b1, ... b26)
///           indicate which channels are to be scanned (1 = scan, 0 = do not scan) for each of the 27 valid channels.
///			\param scanDuration
///           A value used to calculate the length of time to spend scanning each channel.
///			  The time spent scanning each channel is (aBaseSuperframeDuration * (2n + 1)) symbols 
///			\param beaconOrder
///           In star mode or tree mode this specifies the beacon order of the network that the higher layers wish to form.
///           In MESH_MODE there are no beacons and this parameter will be set equal to 0x0f. 
///			\param superframeOrder
///           In star mode or tree mode this specifies the superframe order of the network that the higher layers wish to form.    
///           In MESH_MODE there are no beacons and this parameter may be omitted. If the parameter is supplied, it will be ignored.
///			\param panID
///           An optional PAN identifier that may be supplied if higher layers wish to establish this network with a predetermined identifier. 
///           If PANId is not specified, i.e. a NULL value is given, then the NWK layer will choose a PAN ID.
///			\param batteryLifeExtension
///           If this value is TRUE, the NLME will request that the ZigBee coordinator is 
///                  started supporting battery life extension mode.
///           If this value is FALSE, the NLME will request that the ZigBee coordinator is started
///                  without supporting battery life extension mode.
//   	RETURN VALUE:
///      	\return INVALID_REQUEST,STARTUP_FAILURE or any status value returned from the mlmeStartRequest Function.
//-------------------------------------------------------------------------------------------------------
NWK_ENUM nlmeNetworkFormationRequest(UINT32 scanChannels, BYTE scanDuration, BYTE beaconOrder, BYTE superframeOrder, WORD panID, BOOL batteryLifeExtension) large;  

//-------------------------------------------------------------------------------------------------------
//   void nlmeJoinRequest(WORD panId, BOOL joinAsRouter, BOOL rejoinNetwork, UINT32 scanChannels, BYTE scanDuration, BYTE powerSource, BYTE rxOnWhenIdle, BYTE macSecurity)
//
//   DESCRIPTION:
///      \brief This primitive allows the next higher layer to request to join a network either through association or
///            directly or to re-join a network if orphaned. 
///
//   PARAMETERS:
///      \param panId
///          The PAN identifier of the network to attempt to join or re-join. . The 2 highest-order bits of this parameter
///              are reserved and shall be set to 0  (0x00000x3fff)
///      \param joinAsRouter
///          The parameter is TRUE if the device is attempting to join the network in the capacity of a ZigBee router.
///             It is FALSE otherwise.
///          The parameter is valid in requests to join through association and ignored in requests to join directly 
///              or to re-join through orphaning.
///      \param rejoinNetwork
///          The parameter is TRUE if the device is joining directly or rejoining the network using the orphaning procedure.
///          The parameter is FALSE if the device is requesting to join a network through association.
///      \param scanChannels
///          The five most significant bits (b27, ... ,b31) are reserved. The 27 least significant bits (b0, b1, ... b26)
///           indicate which channels are to be scanned (1 = scan, 0 = do not scan) for each of the 27 valid channels.
///      \param scanDuration
///           A value used to calculate the length of time to spend scanning each channel.
///      \param powerSource
///          This parameter becomes a part of the CapabilityInformation parameter passed to the mlmeAssociateRequest function
///             that is generated as the result of a successful executing of a NWK join.
///          0x01 = Mains-powered device,   0x00 = other power source.
///      \param rxOnWhenIdle
///          This parameter indicates whether the device can be expected to receive packets over the air during idle
///               portions of the active portion of its superframe.
///                  0x01 = The receiver is enabled when the device is idle.
///                  0x00 = The receiver may be disabled when the device is idle.
///          This parameter shall have a value of 0x01 for ZigBee coordinators and ZigBee routers
///                 operating in a nonbeacon-oriented network.
///      \param macSecurity
///          This parameter becomes a part of the CapabilityInformation parameter passed to the mlmeAssociateRequest function
///                that is generated as the result of a successful executing of a NWK join.
///             0x01 = MAC security enabled,   0x00 = MAC security disabled.
//-------------------------------------------------------------------------------------------------------
void nlmeJoinRequest(WORD panId, BOOL joinAsRouter, BOOL rejoinNetwork, UINT32 scanChannels, BYTE scanDuration, BYTE powerSource, BYTE rxOnWhenIdle, BYTE macSecurity) large;



//-------------------------------------------------------------------------------------------------------
//   void nlmeJoinIndication(NLME_JOIN_INDICATION *pNJI)
//
//   DESCRIPTION:
//       This function allows the next higher layer of a ZigBee coordinator or ZigBee router to be notified 
//          when a new device has successfully joined its network by association.
//
//   PARAMETERS:
//       NLME_JOIN_INDICATION *pNJI
//          Pointer to the NLME_JOIN_INDICATION join indication struct.
//-------------------------------------------------------------------------------------------------------
void nlmeJoinIndication(NLME_JOIN_INDICATION *pNJI);


//-------------------------------------------------------------------------------------------------------
//   void nlmeJoinConfirm(WORD panId, NWK_ENUM Status)
//
//   DESCRIPTION:
//      This function allows the next higher layer to be notified of the results of its request to join a network.
//
//   PARAMETERS;
//      WORD panId
//         The PAN identifier from the nlmeJoinRequest to which this is a confirmation. The 2 highest-order bits
//              of this parameter are reserved and should be set to 0. (0x00000x3fff or NULL)
//      NWK_ENUM Status
//         INVALID_REQUEST,NOT_PERMITTED or any status value returned from the mlmeAssociateConfirm function 
//              or the mlmeScanConfirm function.
//-------------------------------------------------------------------------------------------------------
void nlmeJoinConfirm(WORD panId, NWK_ENUM Status);

//-------------------------------------------------------------------------------------------------------
//   void nlmeDirectJoinRequest(ADDRESS deviceAddress, BYTE capabilityInformation)
//
//   DESCRIPTION:
///       \brief This function allows the next higher layer of a ZigBee coordinator 
///			or router to request to directly join another device to its network.
///
//   PARAMETERS:
///       \param deviceAddress
///           The IEEE address of the device to be directly joined.
///       \param capabilityInformation
///           The operating capabilities of the device being directly joined.
//-------------------------------------------------------------------------------------------------------
void nlmeDirectJoinRequest(ADDRESS deviceAddress, CAPABILITY_INFORMATION_FIELD capabilityInformation);



//-------------------------------------------------------------------------------------------------------
//   void nlmeDirectJoinConfirm(ADDRESS deviceAddress,NWK_ENUM status)
//
//   DESCRIPTIOIN:
//       This function notify the next higher layer of a ZigBee coordinator or router the results of
//           its request to directly join another device to its network.
//
//   PARAMETERS:
//       ADDRESS deviceAddress
//           The 64-bit IEEE address in the request to which this is a confirmation.
//   NWK_ENUM status
//       SUCCESS,ALREADY_PRESENT,TABLE_FULL
//-------------------------------------------------------------------------------------------------------
void nlmeDirectJoinConfirm(ADDRESS deviceAddress,NWK_ENUM status); 

//-------------------------------------------------------------------------------------------------------
//  void nlmeLeaveRequest(ADDRESS deviceAddress)
//  DESCRIPTION:
///      The Function is used to request that it or another device leaves the network.
//
//  PARAMETERS:
///      \param deviceAddress
///          The 64-bit IEEE address of the entity to be removed from the network or NULL
///               if the device removes itself from the network.
//-------------------------------------------------------------------------------------------------------
void nlmeLeaveRequest(ADDRESS deviceAddress);



//-------------------------------------------------------------------------------------------------------
//   void nlmeLeaveIndication(ADDRESS deviceAddress)
//
//   DESCRIPTION:
//      This primitive allows the next higher layer of a ZigBee device to be notified if that device has been
//      removed from the network by its parent. It also allows the next higher layer on a ZigBee router or ZigBee
//      coordinator to be informed if one of its associated devices has left the network by disassociation.
//   PARAMETERS:
//      ADDRESS  deviceAddress
//          The 64-bit IEEE address of the entity to be removed from the network or NULL
//               if the device removes itself from the network.
//-------------------------------------------------------------------------------------------------------
void nlmeLeaveIndication(ADDRESS deviceAddress);


//-------------------------------------------------------------------------------------------------------
//   void nlmeLeaveConfirm(ADDRESS deviceAddress,NWK_ENUM status)
//   DESCRIPTION:
//      The Function allows the next higher layer to be notified of the results of its request for itself or another
//      device to leave the network.
//   PRAMETERS:
//      ADDRESS deviceAddress
//          The 64-bit IEEE address in the request to which this is a confirmation or null 
//              if the device requested to remove itself from the network. 
//      NWK_ENUM status
//          INVALID_REQUEST,UNKNOWN_DEVICE or any status value returned from mcpsDisassociateConfirm function.
//--------------------------------------------------------------------------------------------------------
void nlmeLeaveConfirm(ADDRESS deviceAddress,NWK_ENUM status);

//--------------------------------------------------------------------------------------------------------
//   void nlmeGetRequest(NWK_NIB_ATTR NIBAttribute)
//
//   DESCRIPTION:
///      \brief This function allows the next higher layer to read the value of an attribute from the NIB.
//
//   PARAMETERS:
///       \param NIBAttribute
///          The identifier of the NIB attribute to read.
//-------------------------------------------------------------------------------------------------------
void nlmeGetRequest(NWK_NIB_ATTR NIBAttribute);

//-------------------------------------------------------------------------------------------------------
//   NWK_EMUN nlmePermitJoiningRequest(BYTE permitDuration)
//
//   DESCRIPTION:
///       \brief This Function allows the next higher layer of a ZigBee coordinator or router to set its MAC sub-layer
///             association permit flag for a fixed period during which it may accept devices onto its network. 
//   PARAMETERS:
///       \param permitDuration
///           The length of time in seconds during which the ZigBee coordinator or router will allow associations. 
///           The values 0x00 and 0xff indicate that permission is disabled or enabled,respectively, 
///               without a specified time limit. 
//   RETURN VALUE:
///       \return INVALID_REQUEST or any status returned from the mlmeSetRequest function.
//-------------------------------------------------------------------------------------------------------
NWK_ENUM nlmePermitJoiningRequest(BYTE permitDuration);

//-------------------------------------------------------------------------------------------------------
//   NWK_EMUN nlmeStartRouterRequest(BYTE beaconOrder, BYTE superframeOrder, BOOL BatteryLifeExtension)
//
//   DESCRIPTION:
///	     \brief  This Funciton allows the next higher layer of a ZigBee router to initialize or change its superframe configuration.
///            It also allows the next higher layer of a ZigBee coordinator to change its superframe configuration.
//   PARAMETERS:
//       BYTE beaconOrder
///		 \param beaconOrder
///			 In star mode or tree mode this specifies the beacon order of the network that the higher layers wish to form.
///           In MESH_MODE there are no beacons and this parameter will be set equal to 0x0f. 
//       BYTE superframeOrder
///		 \param superframeOrder	
///			In star mode or tree mode this specifies the superframe order of the network that the higher layers wish to form.    
///           In MESH_MODE there are no beacons and this parameter may be omitted. If the parameter is supplied, it will be ignored.
//       BOOL BatteryLifeExtension
///		 \param BatteryLifeExtension If this value is TRUE, the NLME will request that the ZigBee coordinator is 
///                  started supporting battery life extension mode.
///           If this value is FALSE, the NLME will request that the ZigBee coordinator is started
///                  without supporting battery life extension mode.
//   RETURN VALUE:
///		\return INVALID_REQUEST or any status value (SUCCESS, NO_SHORT_ADDRESS, UNAVAILABLE_KEY
///		 FRAME_TOO_LONG, FAILED_SECURITY_CHECK or INVALID_PARAMETER) returned from the 
///		 mlmeStartRequest function.
//-------------------------------------------------------------------------------------------------------
NWK_ENUM nlmeStartRouterRequest(BYTE beaconOrder, BYTE superframeOrder, BOOL BatteryLifeExtension);

//--------------------------------------------------------------------------------------------------------
//   NWK_ENUM nlmeResetRequest()
//   
//   DESCRIPTION:
///		\brief The function is called to request that the NWK layer performs a reset operation.
//   PARAMETERS:
//       Null.
//   RETURN VALUE:
///       \return Status value returned from the mlmeResetRequest function.(SUCCESS or DISABLE_TRX_FAILURE)
//--------------------------------------------------------------------------------------------------------
NWK_ENUM nlmeResetRequest(void);

//--------------------------------------------------------------------------------------------------------
//   NWK_ENUM nlmeSyncRequest(BOOL track)
//
//   DESCRIPTION:
///       The function is called to synchronize or extract data from its ZigBee coordinator or router.
//
//   PARAMETERS:
///       \param track
///           Whether the synchronization should be maintained for future beacons or not.
///
//   RETURN VALUE:
///       \return SUCCESS,SYNC_FAILURE OR INVALID_PARAMETER
//--------------------------------------------------------------------------------------------------------
NWK_ENUM nlmeSyncRequest(BOOL track);


//--------------------------------------------------------------------------------------------------------
//   void nlmeSyncIndication()
//
//   DESCRIPTION:
//       This function allows the next higher layer to be notified of the loss of synchronization at the MAC sub-layer.
//
//   PARAMETERS:
//       NULL
//
//--------------------------------------------------------------------------------------------------------
void nlmeSyncIndication();	//Edward 08032005 11:20 not implemented. 
							//should process mlmeSyncLossIndication and if BEACON_LOST, generate this one.

//-------------------------------------------------------------------------------------------------------
//   void nlmeSetRequest(NWK_NIB_ATTR NIBAttribute, WORD NIBAttributeLength,void *pNIBAttributeValue)
//
//   DESCRIPTION:
///      \brief This function allows the next higher layer to write the value of an attribute into the NIB.
//
//   PARAMETERS:
///      \param NIBAttribute
///          The identifier of the NIB attribute to be written.
///      \param NIBAttributeLength
///          The length, in octets, of the attribute value being set.
///      \param *pNIBAttributeValue
///          Pointer to the value of the NIB attribute that should be written.
//-------------------------------------------------------------------------------------------------------
void nlmeSetRequest(NWK_NIB_ATTR NIBAttribute, BYTE NIBAttributeLength,void *pNIBAttributeValue);


//-------------------------------------------------------------------------------------------------------
//   void nlmeSetConfirm(NWK_ENUM status,NWK_NIB_ATTR NIBAttribute)
//
//   DESCRIPTION:
///      \brief This function reports the results of an attempt to write a value to a NIB attribute.
//
//   PARAMETERS:
///      \param status
///          SUCCESS,INVALID_PARAMETER or UNSUPPORTED_ATTRIBUTE.
///      \param NIBAttribute
///          The identifier of the NIB attribute that was written.
//-------------------------------------------------------------------------------------------------------
void nlmeSetConfirm(NWK_ENUM status,NWK_NIB_ATTR NIBAttribute);

void netInit();
void UpdatenwkInformationFields(void);
//-------------------------------------------------------------------------------------------------------
extern HS_NET_LAYER_CTRL           xdata  HS_NetLayerCtrl;
extern MSDU_BUFFER                 xdata  MsduRx;
extern MSDU_BUFFER                 xdata  MsduTx;

extern void AODVjrUnicastRreq(void);
extern void AODVjrBroadcastRreq(void);
extern void AODVjrReplyWithRrep(void);
extern void AODVjrUnicastRrep(void);
extern void AODVjrFindNewRroutingPath(void);
extern void SetHsAodvMode(unsigned char byMode);
extern void SetHsBroadcastMode(unsigned char byMode);
extern void HsNetRunSend_BroadcastPacket(void);
extern unsigned char HS_NetBroadcastProcess(void);
extern unsigned char HS_NetBroadcastSM(void);

extern unsigned char  xdata    byNetBroadcastMode;
extern unsigned short xdata    NwkSecondTimer;
extern unsigned char           byRouteRequestId;
extern bit                     NeighBorTableOpenFlag;

extern bit                        bitTimeChange;
extern bit                        bitTimeIntFlagOld;
extern bit                        bitTimeIntFlagNew;



#define AODVjr_RREQ_RETYR_COUNT            3
#define NET_BROADCAST_RETYR_COUNT          3

#define NORMAL_JOIN                        0
#define DIRECT_JOIN                        1

unsigned char  *GetCoordExtendedAddress(void);
unsigned short GetNetShortAddress(void);


void  LoopProceTimeChange(void);
void  LoopProce(void);
void  InitAllSystem(void);

///binary commands for interacting with PC
///The following commands are propriatary.
#define HPP_APS_ZDO_CMD_BEGIN                               0x70
#define HPP_NET_CMD_NULL                                    0
#define HPP_NET_APP_CMD_BEGIN                               0x80
	
#define HPP_NET_APP_CMD_GET_ADC_VALUE                       (HPP_NET_APP_CMD_BEGIN + 1)
#define HPP_NET_APP_CMD_GET_RSSI_VALUE                      (HPP_NET_APP_CMD_BEGIN + 2)
#define HPP_NET_APP_CMD_GET_TEMPERATURE_VALUE               (HPP_NET_APP_CMD_BEGIN + 3)
#define HPP_NET_APP_CMD_GET_SIB                             (HPP_NET_APP_CMD_BEGIN + 4)

#define HPP_NET_APP_CMD_GET_AT_REG                          (HPP_NET_APP_CMD_BEGIN + 6)
#define HPP_NET_APP_CMD_SET_AT_REG                          (HPP_NET_APP_CMD_BEGIN + 7)
#define HPP_NET_APP_CMD_GET_IEEE_ADDRESS                    (HPP_NET_APP_CMD_BEGIN + 8)
#define HPP_NET_APP_CMD_SET_IEEE_ADDRESS                    (HPP_NET_APP_CMD_BEGIN + 9)

#define HPP_NET_APP_CMD_GET_MAC_ADDRESS                     (HPP_NET_APP_CMD_BEGIN + 11)
#define HPP_NET_APP_CMD_GET_VER_INFO                        (HPP_NET_APP_CMD_BEGIN + 12)
#define HPP_NET_APP_CMD_RESET_SYSTEM                        (HPP_NET_APP_CMD_BEGIN + 15)
#define HPP_NET_APP_CMD_DEFAULT_CONFIG                      (HPP_NET_APP_CMD_BEGIN + 16)
#define HPP_NET_APP_CMD_READ_FLASH_PAGE                     (HPP_NET_APP_CMD_BEGIN + 17)
#define HPP_NET_APP_CMD_WRITE_FLASH_PAGE                    (HPP_NET_APP_CMD_BEGIN + 18)

#define HPP_NET_APP_CMD_GET_NIB_NEIGHBOR_TABLE              (HPP_NET_APP_CMD_BEGIN + 19)
#define HPP_NET_APP_CMD_GET_NIB_ROUTING_TABLE               (HPP_NET_APP_CMD_BEGIN + 20)
#define HPP_NET_APP_CMD_GET_NIB_ROUTE_DISCOVERY_TABLE       (HPP_NET_APP_CMD_BEGIN + 21)

#define HPP_NET_APP_CMD_GET_BLACKLIST_TABLE                 (HPP_NET_APP_CMD_BEGIN + 28)
#define HPP_NET_APP_CMD_SET_BLACKLIST_TABLE                 (HPP_NET_APP_CMD_BEGIN + 29)

typedef struct tag_NET_EXT_FLAG
{
    unsigned char  PacketSequence :4 ;
    unsigned char  TTL            :4 ; 
}NET_EXT_FLAG;

typedef struct tag_HPP_NET_HEADER
{  
    unsigned char  byNetFlag;  
	NET_EXT_FLAG   NetExtFlag;
    unsigned char  byNetAddrWhoSend;           
	unsigned char  byNetSrcAddr;
	unsigned char  byNetDestAddr;
}HPP_NET_HEADER;

typedef union tagRF_BUFFER_DESC
{
    HPP_NET_HEADER  Header;
    unsigned char   Buffer[256];
}RF_BUFFER_DESC;

#define NET_CMD_IS_SELF             0
#define NET_CMD_IS_USER_IO          1

#define  HPP_NET_DATA               B_0001_0000
#define  HPP_NET_DATA_ACK           B_1001_0000

#define  HPP_NET_COMMAND            B_0010_0000
#define  HPP_NET_COMMAND_ACK        B_1010_0000

#define  HPP_NET_ROUTE              B_0100_0000
#define  HPP_NET_ROUTE_ACK          B_1100_0000

#define  HPP_NET_ERROR              B_1111_0000

#define  HPP_NET_CMD_MASK           B_1111_0000
#define  HPP_NET_GET_CMD(s)         (s & HPP_NET_CMD_MASK)

#define  HPP_NET_ACK_MASK           B_1000_0000
#define  HPP_NET_ACK_FLAG           B_0000_1000

#define  GET_LOCAL_NWK_ADDR()       (ModuleCfgInfo.AtCfgInfo.wNwkNodeID)

#endif
