
#ifndef HAL_F121DB_H
#define HAL_F121DB_H


/*******************************************************************************************************
 *******************************************************************************************************
 **************************             F121 REference Design I/O PORTS       **************************
 *******************************************************************************************************
 *******************************************************************************************************/
#ifndef tag_ADC0
#define tag_ADC0
	sfr16 ADC0     = 0xbe;                 // ADC0 data
#endif
sfr16 PCA0     = 0xf9;                 // PCA0 counter
sfr16 PCA0CP0  = 0xfb;                 // PCA0 Module 0 capture
sfr16 PCA0CP1  = 0xfd;                 // PCA0 Module 1 capture
sfr16 PCA0CP2  = 0xe9;                 // PCA0 Module 2 capture
sfr16 PCA0CP3  = 0xeb;                 // PCA0 Module 3 capture
sfr16 PCA0CP4  = 0xed;                 // PCA0 Module 4 capture
sfr16 PCA0CP5  = 0xe1;                 // PCA0 Module 5 capture

//
//-------------------------------------------------------------------------------------------------------
#ifndef tag_SFD_CCA
#define tag_SFD_CCA
	sbit SFD = P1^0;
	sbit CCA = P1^5;
#endif

#ifndef tag_FIFO
#define tag_FIFO
	sbit NFIFOP = P1^2;
	sbit FIFO = P1^4;
#endif

sbit RESETN = P1^6;
sbit VREGEN = P1^7;

#define FIFOP (!NFIFOP)
#define RXOVER (!FIFO && FIFOP)
#define NSS_LOW()    (NSSMD0=0)
#define NSS_HIGH()   (NSSMD0=1)
//-------------------------------------------------------------------------------------------------------
//
//-------------------------------------------------------------------------------------------------------
// P2: bit number defines
#define LED0            0 // P2.0 - Output: LED0
#define LED1            1 // P2.1 - Output: LED1
#define LED2            2 // P2.2 - Output: LED2
#define LED3            3 // P2.3 - Output: LED3
#define LED4            4 // P2.4 - Output: LED4
#define LED5            5 // P2.5 - Output: LED5
#define LED6            6 // P2.6 - Output: LED6
#define LED7            7 // P2.7 - Output: LED7
//-------------------------------------------------------------------------------------------------------
//
//-------------------------------------------------------------------------------------------------------
// P3: bit number defines
sbit NBUTTON0 = P3^0;
sbit NBUTTON1 = P3^1;
sbit NBUTTON2 = P3^2;
sbit NBUTTON3 = P3^3;

#define BUTTON0 (!NBUTTON0)
#define BUTTON1 (!NBUTTON1)
#define BUTTON2 (!NBUTTON2)
#define BUTTON3 (!NBUTTON3)
//-------------------------------------------------------------------------------------------------------


//-------------------------------------------------------------------------------------------------------



//-------------------------------------------------------------------------------------------------------




/*******************************************************************************************************
 *******************************************************************************************************
 **************************                 CC2420 PIN ACCESS                 **************************
 *******************************************************************************************************
 *******************************************************************************************************/


//-------------------------------------------------------------------------------------------------------
// CC2420 pin access

// Pin status
#define FIFO_IS_1()                 FIFO
#define CCA_IS_1()                  CCA
#define RESET_IS_1()                RESETN
#define VREG_IS_1()                 VREGEN
#define FIFOP_IS_1()                FIFOP
#define SFD_IS_1()                  SFD

#define FIFO_IS_ACTIVE()            FIFO
#define CCA_IS_ACTIVE()             CCA
#define RESET_IS_ACTIVE()           !RESETN
#define VREG_IS_ACTIVE()            VREGEN
#define FIFOP_IS_ACTIVE()           FIFOP
#define SFD_IS_ACTIVE()             SFD

// CC2420 reset_n pin
#define SET_RESET_ACTIVE()          RESETN = 0
#define SET_RESET_INACTIVE()        RESETN = 1

// CC2420 voltage regulator enable pin
#define SET_VREG_ACTIVE()           VREGEN = 1
#define SET_VREG_INACTIVE()         VREGEN = 0
//-------------------------------------------------------------------------------------------------------




/*******************************************************************************************************
 *******************************************************************************************************
 **************************                   SERIAL PORTS                    **************************
 *******************************************************************************************************
 *******************************************************************************************************/


//-------------------------------------------------------------------------------------------------------
// UART hardware flow control
//#define CLR_RTS()                   do { ???; } while (0)
//#define SET_RTS()                   do { ???; } while (0)

//#define SET_CTS()                   do { ???; } while (0)
//#define CLR_CTS()                   do { ???; } while (0)
//-------------------------------------------------------------------------------------------------------




/*******************************************************************************************************
 *******************************************************************************************************
 **************************               EXTERNAL INTERRUPTS                 **************************
 *******************************************************************************************************
 *******************************************************************************************************/



// FIFOP on external interrupt 0

#define ENABLE_FIFOP_INT()   IE |= 0x01
#define DISABLE_FIFOP_INT()  IE &= ~0x01

#define ENABLE_FIFOP_INT_FLAG() (IE & 0x01) 

#define CLEAR_FIFOP_INT() \
   do { \
         SFRPAGE = TIMER01_PAGE; \
         TCON   &= ~0x02; \
      } while (0)
//-------------------------------------------------------------------------------------------------------

//-------------------------------------------------------------------------------------------------------



/*******************************************************************************************************
 *******************************************************************************************************
 **************************                        LEDS                       **************************
 *******************************************************************************************************
 *******************************************************************************************************/


//-------------------------------------------------------------------------------------------------------
// LEDs
#define CLR_LED(n)                  do { P2 |= BM(n); } while (0)
#define SET_LED(n)                  do { P2 &= ~BM(n); } while (0)
#define TOGGLE_LED(n)               do { P2 ^= BM(n); } while (0)
#define GET_LED(n)                  (P2 & ~BM(n))
#define INCR_LED()                  do { P2 -= 1; } while (0)
#define DECR_LED()                  do { P2 += 1; } while (0)
#define SET_LED_MASK(n)             do { P2 = (BYTE) ~(n); } while (0)
//-------------------------------------------------------------------------------------------------------


//-------------------------------------------------------------------------------------------------------
// CC2420DB -> STK501 LED mapping

// Clears LED
#define CLR_GLED()                  CLR_LED(0)
#define CLR_YLED()                  CLR_LED(1)
#define CLR_OLED()                  CLR_LED(2)
#define CLR_RLED()                  CLR_LED(3)

// Set LED
#define SET_GLED()                  SET_LED(0)
#define SET_YLED()                  SET_LED(1)
#define SET_OLED()                  SET_LED(2)
#define SET_RLED()                  SET_LED(3)

// Toggle LED
#define TOGGLE_GLED()               TOGGLE_LED(0)
#define TOGGLE_YLED()               TOGGLE_LED(1)
#define TOGGLE_OLED()               TOGGLE_LED(2)
#define TOGGLE_RLED()               TOGGLE_LED(3)

// Get LED
#define GET_GLED()                  GET_LED(0)
#define GET_YLED()                  GET_LED(1)
#define GET_OLED()                  GET_LED(2)
#define GET_RLED()                  GET_LED(3)
//-------------------------------------------------------------------------------------------------------




/*******************************************************************************************************
 *******************************************************************************************************
 **************************               APPLICATION DEBUGGING               **************************
 *******************************************************************************************************
 *******************************************************************************************************/


//-------------------------------------------------------------------------------------------------------
// Controlled application crash (flashes the LEDs forever to indicate an error code)
#define EXCEPTION(n) \
    do { \
        DISABLE_GLOBAL_INT(); \
        SET_LED_MASK(0); \
        halWait_us(50000); \
        SET_LED_MASK(n); \
        halWait_us(50000); \
    } while (TRUE)
//-------------------------------------------------------------------------------------------------------


#endif




/*******************************************************************************************************
 * Revision history:
 *
 * $Log: hal_F121DB.h,v $
 * Revision 1.3  2005/04/11 20:30:41  yangfan
 * *** empty log message ***
 *
 * Revision 1.2  2005/04/01 20:37:44  cvs
 * *** empty log message ***
 *
 * Revision 1.1  2005/03/30 18:19:37  cvs
 * init
 * by rongbin.xue
 * 30/3/2005
 *
 * Revision 1.3  2004/12/26 04:19:35  henk
 * Association  working (12/18/2004)
 *
 * Revision 1.2  2004/12/26 03:59:07  henk
 * Beacon working (12/03/2004)
 *
 * Revision 1.1.1.1  2004/12/19 18:02:23  henk
 * Initial creation
 *
 * Revision 1.5  2004/08/13 13:04:42  jol
 * CC2420 MAC Release v0.7
 *
 *
 *******************************************************************************************************/
