/* ____________________________________________________________________________
#  Copyright (c) 2004
# 	Helicomm Inc.  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are prohibited without the written consents of Helicomm, Inc.
#
#  THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* _____________________________________________________________________________
*
* File:                hal_spi.h
*_______________________________________________________________________________*/
/*
* CVS Revision History:
*   
*    $Id: hal_spi.h,v 1.4 2005/04/11 20:30:41 yangfan Exp $
* 
*/

#ifndef HalSpi_h
#define HalSpi_h

#include "c8051f120.h"                    // SFR declarations


#define SPI_FIFO_READING()  (byFifoRead)  
extern unsigned char idata byFifoRead;


//typedefs

#ifndef tag_UINT8
  #define tag_UINT8
  typedef unsigned char UINT8;
#endif

#ifndef tag_QWORD
	#define tag_QWORD
		#define SIZEOFQWORD 8

		typedef BYTE QWORD[SIZEOFQWORD];

		typedef union {
		  BYTE  Extended[8];
 		  WORD  Short[4];
		}ADDRESS;
#endif

#ifndef tag_UDBYTE
#define tag_UDBYTE
#define BIGENDIAN

#ifdef BIGENDIAN
   typedef union {
      WORD w;
      struct {
         BYTE hi;
         BYTE lo;
      }b;
   } UDBYTE;
#else
   typedef union {
      WORD w;
      struct {
         BYTE lo;
         BYTE hi;
      }b;
   } UDBYTE;
#endif
#endif

// defines
#ifndef tag_SYSCLK_SPI_BITRATE
#define tag_SYSCLK_SPI_BITRATE
	#define SYSCLK (24500000L)         // SYSCLK frequency in Hz
	#define SPI_BITRATE (5000000L)        // SPI bit rate
    //#define SPI_BITRATE (6125000L)        // SPI bit rate
#endif


#if (SYSCLK/2/SPI_BITRATE)<255
   #define SPI0CKR_VALUE (SYSCLK/2/SPI_BITRATE) // modify by yangfan.
#else
   #error "error: SPI bit rate too low!"
#endif

#define NSS_LOW()    (NSSMD0=0)
#define NSS_HIGH()   (NSSMD0=1)

#ifndef tag_FIFO
#define tag_FIFO
	sbit NFIFOP = P1^2;
	sbit FIFO = P1^4;
#endif

#define FIFOP (!NFIFOP)
#define RXOVER (!FIFO && FIFOP)

#define SPI_FLUSH_RX()  do{ SPI_Strobe(CC2420_SFLUSHRX); SPI_Strobe(CC2420_SFLUSHRX); }while(0)
#define SPI_FLUSH_TX()  do{ SPI_Strobe(CC2420_SFLUSHTX); }while(0)

//macro psuedonymes
#define FASTSPI_INIT()                       SPI_Init()
#define FASTSPI_STROBE(s)                    SPI_Strobe(s)
#define FASTSPI_SETREG(a,v)                  SPI_SetReg(a,v)
#define FASTSPI_GETREG(a)                    a = SPI_GetReg()
#define FASTSPI_UPD_STATUS(s)                s = SPI_UpdStatus()
#define FASTSPI_WRITE_RAM_WORD (v,a)         SPI_Write_RAM_Word (v,a)
#define FASTSPI_READ_RAM_WORD (a,v)          v = SPI_Read_RAM_Word (a)
#define FASTSPI_WRITE_RAM_BYTES(p, v, n)     SPI_Write_RAM_Bytes(p, v, n)
#define FASTSPI_READ_RAM_BYTES(p, v, n)      SPI_Read_RAM_Bytes(p, v, n)
#define FASTSPI_WRITE_FIFOBYTE (b)           SPI_Write_FIFO_Byte (b)
#define FASTSPI_WRITE_FIFO (p, n)            SPI_Write_FIFO (p, n)
#define FASTSPI_READ_FIFO_BYTE (b)           b = SPI_Read_FIFO_Byte ()
#define FASTSPI_READ_FIFO (p, n)             SPI_Read_FIFO (p, n)

// Prototypes
void  SPI_Init(void);
BYTE  SPI_Strobe(BYTE);
void  SPI_SetReg(BYTE,WORD) ;
WORD  SPI_GetReg(BYTE, WORD) ;
BYTE  SPI_Upd_Status(void);
void  SPI_Write_RAM_Word (WORD,WORD);
WORD  SPI_Read_RAM_Word (WORD);
void  SPI_Write_RAM_Bytes(BYTE *, WORD, UINT8);
void  SPI_Read_RAM_Bytes(BYTE *, WORD, UINT8);
void  SPI_Write_FIFO_Byte (BYTE);
void  SPI_Write_FIFO (BYTE *, UINT8);
BYTE  SPI_Read_FIFO_Byte (BYTE);
BYTE  SPI_Read_FIFO (BYTE *, UINT8);
void SPI_FlushRX_FIFO (void);

void  SPI_WriteRAM_Bytes(BYTE *, WORD, UINT8) large;
BYTE  SPI_UpdStatus(void);
void  SPI_ReadRAM_Bytes(BYTE *, WORD, UINT8) ;
void  SPI_WriteRAM_Word (WORD,WORD);

void  SPI_MacWriteFIFO (BYTE xdata *lpData, UINT8 nLen);  // Only PCA0MODE1 call.
void  SPI_WriteFIFO (BYTE *, UINT8);

#if 0 // original
BYTE  SPI_ReadFIFO_Byte (BYTE);
#else
BYTE  SPI_ReadFIFO_Byte (void);
#endif

BYTE  SPI_MacReadFIFO (BYTE xdata *lpData, UINT8 nLen); // Only INT0 call.
BYTE  SPI_ReadFIFO (BYTE *, UINT8);

#endif
