////////////////////////////////////////////////////////////////////////////////
//
//                Copyright(c) 2005 WJ Communications, Inc.
//
//                   *** Confidential Company Proprietary
//
//
// DESCRIPTION:
//
//    Header file for crc.c
//
// $RCSfile: crc.h,v $
// $Revision: 1.1 $
//
////////////////////////////////////////////////////////////////////////////////


#ifndef INC_CRC_H
#define INC_CRC_H

#include "types.h"
#include "../include/DataDef.h"

/*
 * Direct CRC does not require 0's to be appended to the message to
 * satisfy the verification property( message+CRC=>0, message+~CRC=>0x10DF).
 * If prepended with 0's it is the same as indirect CRC. The leading 0's can be
 * taken into account by calculate the intiail value from indirect method
 * with 0's fed in.
 * A table driven & a bit-by-bit implementation are included.
 *
 * Indirect CRC requires 0's be appended to the message. A bit-by-bit
 * method and a table driven method are included.
 *
 * Both method results in 0x1D0F as residue.
 *
 * References:
 *  1) http://www.joegeluso.com/software/articles/ccitt.htm
 *  2) http://rcswww.urz.tu-dresden.de/~sr21/crc.html
 */

#define USE_CRC16
///#define USE_CRC8


/*
 * CRC8
 *   Polynomial = X^8 + X^4 + X^3 + X^2 +1
 *   Preload    = 0xFF
 *   Residue    = none
 */
///#define CRC8_PLOY           0x1D
  ///#define CRC8_PRELOAD        0xC4
///#define CRC8_PRELOAD        0xFF
///#define CRC8_RES            0xC4
///#define CRC8_SYN            0x00

/*
 * CRC16
 *   Polynomial = X^16 + X^12 + X^5 + 1
 *   Preload    = 0xFFFF
 *   Residue    = 0x1D0F
 */
#define CRC16_POLY          0x1021
#define CRC16_PRELOAD       0xFFFF
#define CRC16_RES           0x1D0F
#define CRC16_SYN           0x0000

#ifdef USE_CRC16
uint16_t calcFwdBlockCRC(register uint16_t count,
                         register uint16_t crc,
                         const void *buffer);

#endif
#endif

